@@ -1,6 +1,8 @@
 import numpy as np
 from astropy import units as u
 from astropy.time import Time
+import mars_clock
+import os
 
 # Define some constants
 mars_solar_day = 24.*u.hour + 39.*u.minute + 35.244*u.second
@@ -219,7 +221,8 @@ def MY2JD(MY, data_file="Piqueux2015_Table1.csv"):
     """
 
     # Read in data table which must map Mars year to Earth date
-    date_data = np.genfromtxt(data_file, delimiter=',', names=True)
+    data_file_path = os.path.join(mars_clock.DATADIR, data_file)
+    date_data = np.genfromtxt(data_file_path, delimiter=',', names=True)
 
     # Take the floor function
     desired_MY = np.floor(MY)
